#!/bin/bash
# Start mdmstatsd container

# Get script dir
SCRIPT_DIR=$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )

# Source environment variables for the machine to pass to mdmstatsd
source ${SCRIPT_DIR}/mdmstatsd.env
source /etc/profile.d/ap.sh

# Set variables.
# APDOCKER_DOMAIN is set in from the systemd .service file
LINUX_GENEVA_REGISTRY="linuxgeneva-microsoft.azurecr.io${APDOCKER_DOMAIN}"
MDMSTATSD_IMAGE="${LINUX_GENEVA_REGISTRY}/genevamdmstatsd:${AP_MDMSTATSD_IMAGE_TAG}"
MDM_SERVICE_NAME="apgenevamdm"
MDMSTATSD_SERVICE_NAME="apgenevamdmstatsd"
DATAROOT="/ap/data"
DATA_GENEVA="${DATAROOT}/aplinux_geneva"
MDMSTATSD_DATA_DIR="${DATA_GENEVA}/mdmstatsd"
AP_TOOLS_DIR="/ap/app/aptools"

# Pull a fresh ACR connection config every start
# We'll only capture stdout to ACR_CONNECTION_STRING, which will be empty on failure
ACR_CONNECTION_STRING=$(${AP_TOOLS_DIR}/apsecret_refresh_acr.py)
if [ $? -ne 0 ]
then
    echo "WARNING: Could not grab the most recent connection configuration for ACR."
fi

if [ -z "${ACR_CONNECTION_STRING}" ]
then
    echo "ERROR: Could not read the cached connection configuration for ACR."
    exit -1
fi

# Turn the connection string into an array
ACR_CONFIG=( ${ACR_CONNECTION_STRING} )
ACR_CLIENT_ID="${ACR_CONFIG[0]}"
ACR_CLIENT_KEY="${ACR_CONFIG[1]}"

if [ -z "${ACR_CLIENT_ID}" ] || [ -z "${ACR_CLIENT_KEY}" ]
then
    echo "ERROR: Invalid connection configuration cached for ACR."
    exit -1
fi

# Don't bother logging in and pulling the image if its already been done
if [[ "$(docker images -q ${MDMSTATSD_IMAGE} 2> /dev/null)" == "" ]]
then
    # Login to aplinux registry and pull the image
    docker login -u ${ACR_CLIENT_ID} -p ${ACR_CLIENT_KEY} ${LINUX_GENEVA_REGISTRY}
    docker pull ${MDMSTATSD_IMAGE}
    docker logout "${LINUX_GENEVA_REGISTRY}"
fi

# Just in case the container was stopped but not removed (happens during a HardReboot),
# remove the old container. The old container holds a lock on the name that we'll need
# to get things up and running again.
! docker stop ${MDMSTATSD_SERVICE_NAME}
! docker rm -f ${MDMSTATSD_SERVICE_NAME}

if [[ "$(docker inspect -f {{.State.Running}} ${MDM_SERVICE_NAME} 2> /dev/null | tr -d '[:space:]')" == "true" ]]
then
    # Get the container up and automatically clean it up on exit
    docker run --rm --name=${MDMSTATSD_SERVICE_NAME} -v ${MDMSTATSD_DATA_DIR}:/tmp/geneva_mdmstatsd --volumes-from ${MDM_SERVICE_NAME} --net=host --uts=host --ipc="container:${MDM_SERVICE_NAME}" ${MDMSTATSD_IMAGE} /start_statsd.sh
else
    exit 0
fi
